package com.yidian.shenghuoquan.border.ui.widget

import android.content.Context
import android.util.AttributeSet
import android.view.View
import androidx.constraintlayout.widget.ConstraintLayout
import com.yidian.shenghuoquan.border.R
import com.yidian.shenghuoquan.border.databinding.BorderViewOrderConsigneeInfoBinding
import com.yidian.shenghuoquan.border.dto.OrderShippingInfo
import com.yidian.shenghuoquan.border.manager.OrderStatus

/**
 * author: yinjiacheng
 * date: 2021/8/21 15:15
 * description: 订单收货人信息
 */
class OrderConsigneeInfoView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyle: Int = 0) :
  ConstraintLayout(context, attrs, defStyle) {

  private val viewBinding =
    BorderViewOrderConsigneeInfoBinding.bind(View.inflate(getContext(), R.layout.border_view_order_consignee_info, this))

  /**
   * 设置收货人信息
   * @param status 订单状态 确认订单时固定传ORDER_STATUS_CONFIRM
   * @param info 收货人信息
   */
  fun setConsigneeInfo(status: OrderStatus, info: OrderShippingInfo?) {
    if (status != OrderStatus.ORDER_STATUS_UNKNOWN && status != OrderStatus.ORDER_STATUS_CONFIRM) {
      // 订单状态除未知和确认中 收件人信息禁止修改（仅展示）
      disableModify()
    }
    info?.let {
      viewBinding.etConsigneeName.setText(it.receiverName)
      viewBinding.etConsigneePhone.setText(it.receiverMobile)
    }
  }

  /**
   * 禁止修改
   */
  fun disableModify() {
    viewBinding.etConsigneeName.keyListener = null
    viewBinding.etConsigneePhone.keyListener = null
  }

}
